-- Function: 'removeUnwantedLogFields' is used to remove specific unwanted fields from log records for st (super-tenant) events.
function removeUnwantedLogFields(tag, timestamp, record)
    local cleaned_record = record
   
    cleaned_record["file"], cleaned_record["kubernetes"], cleaned_record["IKSlogs"], cleaned_record["node_name"], cleaned_record["meta"] = nil
    
    -- Remove "saveServiceCopy" key-value pair from the "message" field
    if cleaned_record.message then
        cleaned_record.message = cleaned_record.message:gsub('"saveServiceCopy"%s*:%s*([^,}]+),?%s?', ''):gsub(',%s*}', '}')
    end

    -- Extracting the service name from the tag
    local _, _, service_name = tag:match('([^%.]+)%.([^%.]+)%.([^%.]+)')
    if service_name then
        -- Assigning the service name to the 'app' field in the record
        cleaned_record["app"] = service_name
    end

    return 1, timestamp, cleaned_record
end


-- Function: 'removeSTFields'
-- Description: This function removes specific fields, namely "logSourceCRN" and "saveServiceCopy", from log records. These removals are targeted at events that meet the following criteria:
--   1. The 'saveServiceCopy' field value is true.
--   2. The events are routed to the service instance itself.
--   3. The events are not directed to the customer utilizing the respective service.
function removeSTFields(tag, timestamp, record)
    local cleaned_record = record

    -- Remove the "logSourceCRN" and "saveServiceCopy" key-value pair from within the "message" field
    if cleaned_record.message then
        cleaned_record.message = cleaned_record.message:gsub('"logSourceCRN"%s*:%s*([^,}]+),?%s?', ''):gsub('"saveServiceCopy"%s*:%s*([^,}]+),?%s?', ''):gsub(',%s*}', '}')
    end

    return 1, timestamp, cleaned_record
end

